  /**
 * The MySensors Arduino library handles the wireless radio link and protocol
 * between your home built sensors/actuators and HA controller of choice.
 * The sensors forms a self healing radio network with optional repeaters. Each
 * repeater and gateway builds a routing tables in EEPROM which keeps track of the
 * network topology allowing messages to be routed to nodes.
 *
 * Created by Henrik Ekblad <henrik.ekblad@mysensors.org>
 * Copyright (C) 2013-2015 Sensnology AB
 * Full contributor list: https://github.com/mysensors/Arduino/graphs/contributors
 *
 * Documentation: http://www.mysensors.org
 * Support Forum: http://forum.mysensors.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 *******************************
 *
 * DESCRIPTION
 * The ArduinoGateway prints data received from sensors on the serial link. 
 * The gateway accepts input on seral which will be sent out on radio network.
 *
 * The GW code is designed for Arduino Nano 328p / 16MHz
 *
 * Wire connections (OPTIONAL):
 * - Inclusion button should be connected between digital pin 3 and GND  
 * - RX/TX/ERR leds need to be connected between +5V (anode) and digital pin 6/5/4 with resistor 270-330R in a series
 *
 * LEDs (OPTIONAL):
 * - To use the feature, uncomment MY_LEDS_BLINKING_FEATURE in MyConfig.h
 * - RX (green) - blink fast on radio message recieved. In inclusion mode will blink fast only on presentation recieved
 * - TX (yellow) - blink fast on radio message transmitted. In inclusion mode will blink slowly
 * - ERR (red) - fast blink on error during transmission error or recieve crc error 
 * 
 */

// Enable debug prints to serial monitor
#define MY_DEBUG 
#define MY_DEBUG_VERBOSE_SIGNING

// Enable leds
#define MY_DEFAULT_LED_BLINK_PERIOD 300
#define MY_DEFAULT_ERR_LED_PIN 4
#define MY_DEFAULT_TX_LED_PIN 5
#define MY_DEFAULT_RX_LED_PIN 6

#define MY_SIGNING_SOFT // Enables software signing
#define MY_SIGNING_REQUEST_SIGNATURES // Always request signing from nodes that support it
#define MY_SIGNING_SOFT_RANDOMSEED_PIN 7 // floating pin for randomness


// Enable and select radio type attached
#define MY_RADIO_NRF24
//#define MY_RADIO_RFM69

// Set LOW transmit power level as default, if you have an amplified NRF-module and
// power your radio separately with a good regulator you can turn up PA level. 
#define MY_RF24_PA_LEVEL RF24_PA_HIGH

// Enable serial gateway
#define MY_GATEWAY_SERIAL

// Define a lower baud rate for Arduino's running on 8 MHz (Arduino Pro Mini 3.3V & SenseBender)
#if F_CPU == 8000000L
#define MY_BAUD_RATE 38400
#endif

// Flash leds on rx/tx/err
//#define MY_LEDS_BLINKING_FEATURE
// Set blinking period
//#define MY_DEFAULT_LED_BLINK_PERIOD 300

// Inverses the behavior of leds
//#define MY_WITH_LEDS_BLINKING_INVERSE

#include <SPI.h>
#include <MySensors.h>  
#include <RCSwitch.h>

RCSwitch wirelessSwitch = RCSwitch();

// add the decimal codes for your switches here
unsigned long switches[] = {12587348, 12587346, 12587345};
int numberOfSwitches = 3;

void setup() { 
  // Setup locally attached sensors
  wirelessSwitch.enableReceive(0);  // Receiver on interrupt 0 => that is pin #2
  //Serial.println("enabled receiver");
}

void presentation() {
 // Present locally attached sensors 
  sendSketchInfo("433 Wireless + Serial Gateway", "13052017");
  
  for (int i = 0; i < numberOfSwitches; i++) {
    present(i, S_DOOR); // s_door has tripped, s_binary might be a choice too 
  }

  //Serial.println("Starting to listen");
}

void loop() { 
  // Send locally attached sensor data here 
  if (wirelessSwitch.available()) {

    unsigned long received_val = wirelessSwitch.getReceivedValue();

    //Serial.print("Pressed button ");
    //Serial.print(received_val);

    for (int i = 0; i < numberOfSwitches; i++) {
      if (received_val == switches[i]) {
        //Serial.print(". Recognized! Its button ");
        ///Serial.println(i);
        send(MyMessage(i, V_TRIPPED).set(true));
      }
    }

    // software debounce
    wait(500);
    wirelessSwitch.resetAvailable();
  }
}





